==> OpenCL-0.8.3.tgz: OpenCL-0.8.3/include/dsa.h <==
/*************************************************
* DSA Header File                                *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#ifndef OPENCL_DSA_H__
#define OPENCL_DSA_H__

#include <opencl/bigint.h>
#include <opencl/pk_keys.h>
#include <opencl/exp.h>

namespace OpenCL {

/*************************************************
* DSA Public Key                                 *
*************************************************/
class DSA_PublicKey : public PK_Verifying_wo_MR_Key
   {
   public:
      bool verify(const byte[], u32bit, const byte[], u32bit) const;

      u32bit max_input_bits() const { return q.bits(); }

      bool check_params() const;
      BigInt get_p() const { return p; }
      BigInt get_q() const { return q; }
      BigInt get_g() const { return g; }
      BigInt get_y() const { return y; }

      DSA_PublicKey& operator=(const DSA_PublicKey&);

      DSA_PublicKey(const BigInt&, const BigInt&,
                    const BigInt&, const BigInt&);
      DSA_PublicKey(const DSA_PublicKey&);
      ~DSA_PublicKey();
   protected:
      DSA_PublicKey() { reducer_q = 0; }
      BigInt p, q, g, y;
      FixedBase_Exp powermod_g_p, powermod_y_p;
      class ModularReducer* reducer_q;
      mutable BigInt t1, r, s;
   };

/*************************************************
* DSA Private Key                                *
*************************************************/
class DSA_PrivateKey : public DSA_PublicKey, public PK_Signing_Key
   {
   public:
      SecureVector<byte> sign(const byte[], u32bit) const;

      bool check_params() const;
      BigInt get_x() const { return x; }

      DSA_PrivateKey(const BigInt&, const BigInt&, const BigInt&,
                     const BigInt& = 0, const BigInt& = 0);
      DSA_PrivateKey(u32bit, u32bit = 160, bool = false);
      DSA_PrivateKey(const byte[], u32bit, u32bit = 1024);
   private:
      bool valid_fips186_p_size(u32bit);
      void keygen_operation();
      BigInt x;
      mutable BigInt k;
   };

}

#endif

==> OpenCL-0.8.4.tgz: OpenCL-0.8.4/include/dsa.h <==
/*************************************************
* DSA Header File                                *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#ifndef OPENCL_DSA_H__
#define OPENCL_DSA_H__

#include <opencl/bigint.h>
#include <opencl/pk_keys.h>
#include <opencl/mod_exp.h>

namespace OpenCL {

/*************************************************
* DSA Public Key                                 *
*************************************************/
class DSA_PublicKey : public PK_Verifying_wo_MR_Key
   {
   public:
      bool verify(const byte[], u32bit, const byte[], u32bit) const;

      u32bit max_input_bits() const { return q.bits(); }

      bool check_params() const;
      const BigInt& get_p() const { return p; }
      const BigInt& get_q() const { return q; }
      const BigInt& get_g() const { return g; }
      const BigInt& get_y() const { return y; }

      DSA_PublicKey(const BigInt&, const BigInt&,
                    const BigInt&, const BigInt&);
   protected:
      DSA_PublicKey() {}
      BigInt p, q, g, y;
      FixedBase_Exp powermod_g_p, powermod_y_p;
      mutable BigInt t1, r, s;
   };

/*************************************************
* DSA Private Key                                *
*************************************************/
class DSA_PrivateKey : public DSA_PublicKey, public PK_Signing_Key
   {
   public:
      SecureVector<byte> sign(const byte[], u32bit) const;

      bool check_params() const;
      const BigInt& get_x() const { return x; }

      DSA_PrivateKey(const BigInt&, const BigInt&, const BigInt&,
                     const BigInt& = 0, const BigInt& = 0);
      DSA_PrivateKey(u32bit, bool = false);
      DSA_PrivateKey(const byte[], u32bit, u32bit = 1024, u32bit = 0);
   private:
      bool valid_fips186_p_size(u32bit) const;
      void keygen_operation();
      BigInt x;
   };

}

#endif
